@@ -3,7 +3,7 @@ package org.ddahl.rscala.server
 class ScalaInterpreterAdapter(val interpreter: scala.tools.nsc.interpreter.IMain) extends InterpreterAdapter {
 
   def interpret(line: String): Unit = interpreter.interpret(line)
-  def eval(line: String): Unit = interpreter.interpret(line)
+  def eval(line: String): Unit = interpreter.eval(line)
   def bind(name: String, boundType: String, value: Any): Unit = interpreter.bind(name,boundType,value)
   def mostRecentVar: String = interpreter.mostRecentVar
   def valueOfTerm(id: String): Option[Any] = interpreter.valueOfTerm(id)
